.. _library-core-index:

****
Core
****

The core package holds the modules that can be expected to be used widely in all projects working with NEO data structures.

.. toctree::
   :maxdepth: 2

   bloomfilter
   ecc
   merkletree
   serialization
   uint
